@@ -14,6 +14,7 @@ from typing import (
 )
 
 from narwhals._compliant.typing import CompliantNamespaceAny, CompliantNamespaceT_co
+from narwhals._utils import Implementation, Version
 from narwhals.dependencies import (
     get_cudf,
     get_modin,
@@ -27,7 +28,6 @@ from narwhals.dependencies import (
     is_pyspark_dataframe,
     is_sqlframe_dataframe,
 )
-from narwhals.utils import Implementation, Version
 
 if TYPE_CHECKING:
     from types import ModuleType
@@ -101,27 +101,38 @@ if TYPE_CHECKING:
     class _NativeDask(Protocol):
         _partition_type: type[pd.DataFrame]
 
-    class _NativeCuDF(Protocol):
+    class _CuDFDataFrame(NativeFrame, Protocol):
         def to_pylibcudf(self, *args: Any, **kwds: Any) -> Any: ...
 
+    class _CuDFSeries(NativeSeries, Protocol):
+        def to_pylibcudf(self, *args: Any, **kwds: Any) -> Any: ...
+        def where(self, cond: Any, other: Any = ..., **kwds: Any) -> Any: ...
+
     class _NativeIbis(Protocol):
         def sql(self, *args: Any, **kwds: Any) -> Any: ...
         def __pyarrow_result__(self, *args: Any, **kwds: Any) -> Any: ...
         def __pandas_result__(self, *args: Any, **kwds: Any) -> Any: ...
         def __polars_result__(self, *args: Any, **kwds: Any) -> Any: ...
 
-    class _ModinDataFrame(Protocol):
+    class _ModinDataFrame(NativeFrame, Protocol):
         _pandas_class: type[pd.DataFrame]
 
-    class _ModinSeries(Protocol):
+    class _ModinSeries(NativeSeries, Protocol):
         _pandas_class: type[pd.Series[Any]]
 
+        def where(self, cond: Any, other: Any = ..., **kwds: Any) -> Any: ...
+
     _NativePolars: TypeAlias = "pl.DataFrame | pl.LazyFrame | pl.Series"
     _NativeArrow: TypeAlias = "pa.Table | pa.ChunkedArray[Any]"
     _NativeDuckDB: TypeAlias = "duckdb.DuckDBPyRelation"
     _NativePandas: TypeAlias = "pd.DataFrame | pd.Series[Any]"
     _NativeModin: TypeAlias = "_ModinDataFrame | _ModinSeries"
-    _NativePandasLike: TypeAlias = "_NativePandas | _NativeCuDF | _NativeModin"
+    _NativeCuDF: TypeAlias = "_CuDFDataFrame | _CuDFSeries"
+    _NativePandasLikeSeries: TypeAlias = "pd.Series[Any] | _CuDFSeries | _ModinSeries"
+    _NativePandasLikeDataFrame: TypeAlias = (
+        "pd.DataFrame | _CuDFDataFrame | _ModinDataFrame"
+    )
+    _NativePandasLike: TypeAlias = "_NativePandasLikeDataFrame |_NativePandasLikeSeries"
     _NativeSQLFrame: TypeAlias = "SQLFrameDataFrame"
     _NativePySpark: TypeAlias = "pyspark_sql.DataFrame"
     _NativePySparkConnect: TypeAlias = "PySparkConnectDataFrame"
@@ -275,8 +286,8 @@ class Namespace(Generic[CompliantNamespaceT_co]):
     @overload
     @classmethod
     def from_native_object(
-        cls, native: _NativePandasLike, /
-    ) -> Namespace[PandasLikeNamespace]: ...
+        cls, native: _NativePandas, /
+    ) -> Namespace[PandasLikeNamespace[pd.DataFrame, pd.Series[Any]]]: ...
 
     @overload
     @classmethod
@@ -302,6 +313,24 @@ class Namespace(Generic[CompliantNamespaceT_co]):
     @classmethod
     def from_native_object(cls, native: _NativeIbis, /) -> Namespace[IbisNamespace]: ...
 
+    @overload
+    @classmethod
+    def from_native_object(
+        cls, native: _NativeModin, /
+    ) -> Namespace[PandasLikeNamespace[_ModinDataFrame, _ModinSeries]]: ...
+
+    @overload
+    @classmethod
+    def from_native_object(
+        cls, native: _NativeCuDF, /
+    ) -> Namespace[PandasLikeNamespace[_CuDFDataFrame, _CuDFSeries]]: ...
+
+    @overload
+    @classmethod
+    def from_native_object(
+        cls, native: _NativePandasLike, /
+    ) -> Namespace[PandasLikeNamespace[Any, Any]]: ...
+
     @overload
     @classmethod
     def from_native_object(
